@@ -1,6 +1,5 @@
 use std::fmt::{Display, Formatter, Debug};
 //use std::backtrace::Backtrace;
-use std::option::NoneError;
 use anyhow::{anyhow};
 use std::time::SystemTimeError;
 //use std::time::SystemTimeError;
@@ -34,12 +33,6 @@ impl Into<anyhow::Error> for DpError {
         self.error
     }
 }
-
-impl From<NoneError> for DpError {
-    fn from(_: NoneError) -> Self {
-        DpError::new(anyhow!("None Error"))
-    }
-}
 impl From<anyhow::Error> for DpError {
     fn from(e: anyhow::Error) -> Self {
         Self::new(e)
